==> permission-service-rest-api-10.3.10-sources.jar: ai/digital/deploy/permissions/api/rest/v2/impl/ExtendedReferencedPermissionsController.scala <==
package ai.digital.deploy.permissions.api.rest.v2.impl

import ai.digital.deploy.permissions.api.rest.dto._
import ai.digital.deploy.permissions.api.rest.dto.converters.RoleConverter._
import ai.digital.deploy.permissions.api.rest.dto.converters.RoleWithReferencedPermissionsConverter._
import ai.digital.deploy.permissions.api.rest.v2.ExtendedReferencedPermissionsPaths._
import ai.digital.deploy.permissions.rest.dto.validation.IsUuid
import ai.digital.deploy.permissions.service.ReferencedPermissionService
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation._

import java.util.{UUID, Set => JSet}
import javax.validation.Valid
import scala.jdk.CollectionConverters._

@Validated
@RestController
@RequestMapping(Array(BASE_PATH))
class ExtendedReferencedPermissionsController(referencedPermissionService: ReferencedPermissionService) {
  @PatchMapping(Array(EDIT_PERMISSIONS_PATH))
  def editPermissions(
    @IsUuid @PathVariable referenceId: String,
    @PathVariable roleName: String,
    @Valid
    @RequestBody editRolePermissionsRequest: EditRolePermissionsRequest
  ): RoleWithReferencedPermissionsDto = {
    val uuid = UUID.fromString(referenceId)
    val (role, permissions) = referencedPermissionService.edit(
      uuid,
      roleName,
      editRolePermissionsRequest.addedPermissions.asScala.toList,
      editRolePermissionsRequest.removedPermissions.asScala.toList
    )
    RoleWithReferencedPermissionsDto(role, uuid, permissions)
  }

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_ROLE_ID, PARAM_PERMISSIONS))
  def getReferencesForRole(@Valid dto: GetReferencedPermissionsForRoleIdDto): JSet[UUID] =
    referencedPermissionService.getReferencesForRole(UUID.fromString(dto.roleId), dto.permissions.asScala.toList).asJava

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_ROLE_IDS, PARAM_PERMISSIONS))
  def getReferencesForRole(@Valid dto: GetReferencedPermissionsForRoleIdsDto): JSet[UUID] =
    referencedPermissionService
      .getReferencesForRoles(dto.roleIds.asScala.map(UUID.fromString).toList, dto.permissions.asScala.toList).asJava

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_ROLE_NAME, PARAM_PERMISSIONS))
  def getReferencesForRoleName(@Valid dto: GetReferencedPermissionsForRoleNameDto): JSet[UUID] =
    referencedPermissionService.getReferencesForRoleName(dto.roleName, dto.permissions.asScala.toList).asJava

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_PRINCIPAL_NAME, PARAM_PERMISSIONS))
  def getReferencesForPrincipal(@Valid dto: GetReferencedPermissionsForPrincipalDto): JSet[UUID] =
    referencedPermissionService.getReferencesForPrincipalName(dto.principalName, dto.permissions.asScala.toList).asJava

  @DeleteMapping(value = Array(REFERENCE_PERMISSIONS_PATH))
  def deleteForReference(@IsUuid @PathVariable referenceId: String): Unit =
    referencedPermissionService.removeForReference(UUID.fromString(referenceId))

  @DeleteMapping(value = Array(DELETE_ALL_PATH))
  def deleteAll(): Unit =
    referencedPermissionService.removeAll()

}

==> permission-service-rest-api-10.4.0-1005.817-sources.jar: ai/digital/deploy/permissions/api/rest/v2/impl/ExtendedReferencedPermissionsController.scala <==
package ai.digital.deploy.permissions.api.rest.v2.impl

import ai.digital.deploy.permissions.api.rest.dto._
import ai.digital.deploy.permissions.api.rest.dto.converters.RoleConverter._
import ai.digital.deploy.permissions.api.rest.dto.converters.RoleWithReferencedPermissionsConverter._
import ai.digital.deploy.permissions.api.rest.v2.ExtendedReferencedPermissionsPaths._
import ai.digital.deploy.permissions.api.rest.v2.ExtendedReferencedPermissionsResource
import ai.digital.deploy.permissions.service.ReferencedPermissionService
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation._

import java.util.{UUID, Set => JSet}
import scala.jdk.CollectionConverters._

@Validated
@RestController
@RequestMapping(Array(BASE_PATH))
class ExtendedReferencedPermissionsController(referencedPermissionService: ReferencedPermissionService)
    extends ExtendedReferencedPermissionsResource {
  @PatchMapping(Array(EDIT_PERMISSIONS_PATH))
  override def editPermissions(
    @PathVariable referenceId: String,
    @PathVariable roleName: String,
    @RequestBody editRolePermissionsRequest: EditRolePermissionsRequest
  ): RoleWithReferencedPermissionsDto = {
    val uuid = UUID.fromString(referenceId)
    val (role, permissions) = referencedPermissionService.edit(
      uuid,
      roleName,
      editRolePermissionsRequest.addedPermissions.asScala.toList,
      editRolePermissionsRequest.removedPermissions.asScala.toList
    )
    RoleWithReferencedPermissionsDto(role, uuid, permissions)
  }

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_ROLE_ID, PARAM_PERMISSIONS))
  override def getReferencesForRole(dto: GetReferencedPermissionsForRoleIdDto): JSet[UUID] =
    referencedPermissionService.getReferencesForRole(UUID.fromString(dto.roleId), dto.permissions.asScala.toList).asJava

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_ROLE_NAME, PARAM_PERMISSIONS))
  override def getReferencesForRoleName(dto: GetReferencedPermissionsForRoleNameDto): JSet[UUID] =
    referencedPermissionService.getReferencesForRoleName(dto.roleName, dto.permissions.asScala.toList).asJava

  @GetMapping(value = Array(GET_REFERENCES), params = Array(PARAM_PRINCIPAL_NAME, PARAM_PERMISSIONS))
  override def getReferencesForPrincipal(dto: GetReferencedPermissionsForPrincipalDto): JSet[UUID] =
    referencedPermissionService.getReferencesForPrincipalName(dto.principalName, dto.permissions.asScala.toList).asJava

  @DeleteMapping(value = Array(REFERENCE_PERMISSIONS_PATH))
  override def deleteForReference(@PathVariable referenceId: String): Unit =
    referencedPermissionService.removeForReference(UUID.fromString(referenceId))

  @DeleteMapping(value = Array(DELETE_ALL_PATH))
  override def deleteAll(): Unit =
    referencedPermissionService.removeAll()

}
